quadmompy.qbmm package
======================

Submodules
----------

quadmompy.qbmm.multivariate module
----------------------------------

.. automodule:: quadmompy.qbmm.multivariate
   :members:
   :undoc-members:
   :show-inheritance:

quadmompy.qbmm.qbmm module
--------------------------

.. automodule:: quadmompy.qbmm.qbmm
   :members:
   :undoc-members:
   :show-inheritance:

quadmompy.qbmm.univariate module
--------------------------------

.. automodule:: quadmompy.qbmm.univariate
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: quadmompy.qbmm
   :members:
   :undoc-members:
   :show-inheritance:
